@@ -1,5 +1,5 @@
 "boa.plot.title" <-
-function(text = boa.par("title"))
+function(text)
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
 {
